@@ -6,7 +6,13 @@
 
 #include "ekos/focus/focusalgorithms.h"
 
+#include <QtGlobal>
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+#include <QtTest/QTest>
+#else
 #include <QTest>
+#endif
+
 #include <memory>
 
 #include <QObject>
