@@ -89,6 +89,10 @@ FilterManager::FilterManager(QWidget *parent) : QDialog(parent)
     lastAFAltDelegate = new DoubleDelegate(m_FilterView, 0.0, 90.0, 1.0);
     m_FilterView->setItemDelegateForColumn(FM_LAST_AF_ALT, lastAFAltDelegate);
 
+    // Last AF solution datetime delegate
+    lastAFDTDelegate = new DatetimeDelegate(m_FilterView, DATETIME_FORMAT, "2025-01-01", "2100-01-01", false);
+    m_FilterView->setItemDelegateForColumn(FM_LAST_AF_DATETIME, lastAFDTDelegate);
+
     // Ticks / °C delegate
     ticksPerTempDelegate = new DoubleDelegate(m_FilterView, -10000.0, 10000.0, 1.0);
     m_FilterView->setItemDelegateForColumn(FM_TICKS_PER_TEMP, ticksPerTempDelegate);
@@ -139,6 +143,10 @@ void FilterManager::createFilterModel()
                                  i18n("The altitude of the last AF solution. Updated automatically by the autofocus process."), Qt::ToolTipRole);
     m_FilterModel->setHeaderData(FM_LAST_AF_ALT, Qt::Horizontal, i18n("Last AF Alt (°Alt)"));
 
+    m_FilterModel->setHeaderData(FM_LAST_AF_DATETIME, Qt::Horizontal,
+                                 i18n("The datetime of the last AF solution. Updated automatically by the autofocus process."), Qt::ToolTipRole);
+    m_FilterModel->setHeaderData(FM_LAST_AF_DATETIME, Qt::Horizontal, i18n("Last AF Datetime"));
+
     m_FilterModel->setHeaderData(FM_TICKS_PER_TEMP, Qt::Horizontal,
                                  i18n("The number of ticks per °C increase in temperature. +ve for outward focuser movement"), Qt::ToolTipRole);
     m_FilterModel->setHeaderData(FM_TICKS_PER_TEMP, Qt::Horizontal, i18n("Ticks / °C"));
@@ -296,6 +304,7 @@ void FilterManager::reloadFilters()
         fp->absFocusPos       = record.value("AbsoluteFocusPosition").toInt();
         fp->focusTemperature  = record.value("FocusTemperature").toDouble();
         fp->focusAltitude     = record.value("FocusAltitude").toDouble();
+        fp->focusDatetime     = record.value("FocusDatetime").toString();
         fp->focusTicksPerTemp = record.value("FocusTicksPerTemp").toDouble();
         fp->focusTicksPerAlt  = record.value("FocusTicksPerAlt").toDouble();
         fp->wavelength        = record.value("Wavelength").toInt();
@@ -408,19 +417,13 @@ void FilterManager::refreshFilterPosition()
 bool FilterManager::setFilterPosition(uint8_t position, FilterPolicy policy)
 {
     // Position 1 to Max
-    if (position > m_ActiveFilters.count())
+    if (position > m_ActiveFilters.count() || m_currentFilterPosition < 1 || position < 1)
         return false;
 
     m_Policy = policy;
     currentFilter = m_ActiveFilters[m_currentFilterPosition - 1];
     targetFilter = m_ActiveFilters[position - 1];
 
-    if (currentFilter == targetFilter)
-    {
-        emit ready();
-        return true;
-    }
-
     buildOperationQueue(FILTER_CHANGE);
 
     executeOperationQueue();
@@ -486,6 +489,15 @@ void FilterManager::buildOperationQueue(FilterState operation)
     {
         case FILTER_CHANGE:
         {
+            // Setup whether we'll run an Autofocus after the Filter Change. The normal reason is that a Filter
+            // Change has been requested but there is also a condition whereby a previous filter change worked but
+            // the associated Autofocus failed. In the latter case, the currentFilter == targetFilter so no need to
+            // change the filter but we'll still need to retry Autofocus.
+            bool runAF = false;
+            if (m_FocusReady && (m_Policy & AUTOFOCUS_POLICY) && targetFilter->useAutoFocus())
+                if ((targetFilter != currentFilter) || (m_LastAFFailed.value(targetFilter->color(), FALSE)))
+                    runAF = true;
+
             if ( (m_Policy & CHANGE_POLICY) && targetFilter != currentFilter)
                 m_useTargetFilter = true;
 
@@ -503,7 +515,7 @@ void FilterManager::buildOperationQueue(FilterState operation)
 
             }
 
-            if (m_FocusReady && (m_Policy & AUTOFOCUS_POLICY) && targetFilter->useAutoFocus())
+            if (runAF)
                 operationQueue.enqueue(FILTER_AUTOFOCUS);
         }
         break;
@@ -712,6 +724,8 @@ bool FilterManager::setFilterAbsoluteFocusDetails(int index, int focusPos, doubl
             m_FilterModel->setData(m_FilterModel->index(i, FM_LAST_AF_SOLUTION), focusPos);
             m_FilterModel->setData(m_FilterModel->index(i, FM_LAST_AF_TEMP), focusTemp);
             m_FilterModel->setData(m_FilterModel->index(i, FM_LAST_AF_ALT), focusAlt);
+            m_FilterModel->setData(m_FilterModel->index(i, FM_LAST_AF_DATETIME),
+                                   KStarsData::Instance()->lt().toString(DATETIME_FORMAT));
             m_FilterModel->submitAll();
             refreshFilterModel();
             return true;
@@ -721,6 +735,17 @@ bool FilterManager::setFilterAbsoluteFocusDetails(int index, int focusPos, doubl
     return false;
 }
 
+bool FilterManager::getAFDatetime(const QString &name, QDateTime &datetime) const
+{
+    auto filterDetails = getFilterByName(name);
+    if (filterDetails)
+    {
+        datetime = filterDetails->focusDatetime();
+        return true;
+    }
+    return false;
+}
+
 QString FilterManager::getFilterLock(const QString &name) const
 {
     auto filterDetails = getFilterByName(name);
@@ -821,6 +846,8 @@ void FilterManager::removeDevice(const QSharedPointer<ISD::GenericDevice> &devic
 
 void FilterManager::setFocusStatus(Ekos::FocusState focusState)
 {
+    setAutofocusStatus(focusState);
+
     if (state == FILTER_AUTOFOCUS)
     {
         switch (focusState)
@@ -842,11 +869,21 @@ void FilterManager::setFocusStatus(Ekos::FocusState focusState)
 
             default:
                 break;
-
         }
     }
 }
 
+void FilterManager::setAutofocusStatus(Ekos::FocusState focusState)
+{
+    if (targetFilter)
+    {
+        if (focusState == FOCUS_COMPLETE)
+            m_LastAFFailed.insert(targetFilter->color(), FALSE);
+        else if (focusState == FOCUS_ABORTED || focusState == FOCUS_FAILED)
+            m_LastAFFailed.insert(targetFilter->color(), TRUE);
+    }
+}
+
 bool FilterManager::syncAbsoluteFocusPosition(int index)
 {
     if (m_FocusReady == false)
@@ -910,6 +947,7 @@ QJsonObject FilterManager::toJSON()
             {"lastafsolution", m_FilterModel->data(m_FilterModel->index(i, FM_LAST_AF_SOLUTION)).toInt()},
             {"lastaftemp", m_FilterModel->data(m_FilterModel->index(i, FM_LAST_AF_TEMP)).toDouble()},
             {"lastafalt", m_FilterModel->data(m_FilterModel->index(i, FM_LAST_AF_ALT)).toDouble()},
+            {"lastafdt", m_FilterModel->data(m_FilterModel->index(i, FM_LAST_AF_DATETIME)).toString()},
             {"tickspertemp", m_FilterModel->data(m_FilterModel->index(i, FM_TICKS_PER_TEMP)).toDouble()},
             {"ticksperalt", m_FilterModel->data(m_FilterModel->index(i, FM_TICKS_PER_ALT)).toDouble()},
             {"wavelength", m_FilterModel->data(m_FilterModel->index(i, FM_WAVELENGTH)).toInt()},
@@ -953,6 +991,7 @@ void FilterManager::setFilterData(const QJsonObject &settings)
         m_FilterModel->setData(m_FilterModel->index(row, FM_LAST_AF_SOLUTION), oneFilter["lastafsolution"].toInt());
         m_FilterModel->setData(m_FilterModel->index(row, FM_LAST_AF_TEMP), oneFilter["lastaftemp"].toDouble());
         m_FilterModel->setData(m_FilterModel->index(row, FM_LAST_AF_ALT), oneFilter["lastafalt"].toDouble());
+        m_FilterModel->setData(m_FilterModel->index(row, FM_LAST_AF_DATETIME), oneFilter["lastafdt"].toString(DATETIME_FORMAT));
         m_FilterModel->setData(m_FilterModel->index(row, FM_TICKS_PER_TEMP), oneFilter["tickspertemp"].toDouble());
         m_FilterModel->setData(m_FilterModel->index(row, FM_TICKS_PER_ALT), oneFilter["ticksperalt"].toDouble());
         m_FilterModel->setData(m_FilterModel->index(row, FM_WAVELENGTH), oneFilter["wavelength"].toInt());
