@@ -112,10 +112,8 @@ class Capture : public QWidget, public Ui::Capture
              * @{
             */
 
-
         /** DBUS interface function.
-             * select the CCD device from the available CCD drivers.
-             * @param device The CCD device name
+             * @return device The CCD device name
              */
         Q_SCRIPTABLE QString camera();
 
@@ -346,10 +344,7 @@ class Capture : public QWidget, public Ui::Capture
         /** DBUS interface function.
              * Clear in-sequence focus settings. It sets the autofocus HFR to zero so that next autofocus value is remembered for the in-sequence focusing.
              */
-        Q_SCRIPTABLE Q_NOREPLY void clearAutoFocusHFR()
-        {
-            mainCamera()->clearAutoFocusHFR();
-        }
+        Q_SCRIPTABLE Q_NOREPLY void clearAutoFocusHFR(const QString &trainname);
 
         /** DBUS interface function.
              * Jobs will NOT be checked for progress against the file system and will be always assumed as new jobs.
@@ -724,8 +719,8 @@ public slots:
         void dither();
         void resetNonGuidedDither();
         void captureTarget(QString targetName);
-        void newImage(SequenceJob *job, const QSharedPointer<FITSData> &data, const QString &trainname);
-        void newExposureProgress(SequenceJob *job, const QString &trainname);
+        void newImage(const QSharedPointer<SequenceJob> &job, const QSharedPointer<FITSData> &data, const QString &trainname);
+        void newExposureProgress(const QSharedPointer<SequenceJob> &job, const QString &trainname);
         void newDownloadProgress(double, const QString &trainname);
         void sequenceChanged(const QJsonArray &sequence);
         void settingsUpdated(const QVariantMap &settings);        
@@ -768,7 +763,7 @@ public slots:
             return mainCamera()->devices();
         }
         // shortcut for the active job
-        SequenceJob *activeJob() const
+        const QSharedPointer<SequenceJob> &activeJob()
         {
             return mainCameraState()->getActiveJob();
         }
