@@ -19,6 +19,7 @@
 #include "indi/indimount.h"
 #include "indi/indirotator.h"
 #include "ekos/auxiliary/rotatorutils.h"
+#include "ksnotification.h"
 
 namespace Ekos
 {
@@ -391,7 +392,10 @@ void CaptureDeviceAdaptor::connectFilterManager(SequenceJobState *state)
 
     connect(state, &SequenceJobState::changeFilterPosition, this, &CaptureDeviceAdaptor::setFilterPosition);
     connect(state, &SequenceJobState::readFilterPosition, this, &CaptureDeviceAdaptor::updateFilterPosition);
-    connect(this, &CaptureDeviceAdaptor::filterIdChanged, state, &SequenceJobState::setCurrentFilterID);
+    // JEE Make this signal a QueuedConnection to avoid a loop between Capture and FilterManager. This loop can occur where
+    // Capture thinks a filter change or Autofocus is required so signals FilterManager. FilterManager then determines what
+    // is required and if its nothing then immediately signals done to Capture.
+    connect(this, &CaptureDeviceAdaptor::filterIdChanged, state, &SequenceJobState::setCurrentFilterID, Qt::QueuedConnection);
 
     if (m_FilterManager.isNull() == false)
         connect(m_FilterManager.get(), &FilterManager::newStatus, state, &SequenceJobState::setFilterStatus);
@@ -414,7 +418,8 @@ void Ekos::CaptureDeviceAdaptor::updateFilterPosition()
 {
     if (m_FilterManager.isNull())
     {
-        qCritical(KSTARS_EKOS_CAPTURE) << "Filter manager is not initilized yet. Filter wheel missing from train?";
+        qCritical(KSTARS_EKOS_CAPTURE) << "Filter manager is not initialized yet. Filter wheel missing from train?";
+        KSNotification::event(QLatin1String("CaptureFailed"), i18n("Filter manager is not initilized yet. Filter wheel missing from train?"), KSNotification::Capture, KSNotification::Alert);
         emit filterIdChanged(-1);
     }
     else
