@@ -153,6 +153,14 @@ void SequenceJob::setISO(int index)
     }
 }
 
+const QVariant SequenceJob::getRemoteDirectory() const
+{
+    if (getCoreProperty(SJ_RemoteDirectory).toString().isEmpty())
+        return getCoreProperty(SJ_LocalDirectory);
+    else
+        return getCoreProperty(SJ_RemoteDirectory);
+}
+
 QStringList SequenceJob::frameTypes() const
 {
     if (!devices->getActiveCamera())
@@ -201,28 +209,13 @@ void SequenceJob::startCapturing(bool autofocusReady, FITSMode mode)
     state->initCapture(getFrameType(), jobType() == SequenceJob::JOBTYPE_PREVIEW, autofocusReady, mode);
 }
 
-void SequenceJob::capture(FITSMode mode)
+QString SequenceJob::setCameraDeviceProperties()
 {
-    if (!devices.data()->getActiveCamera() || !devices.data()->getActiveChip())
-        return;
-
     // initialize the log entry
     QString logentry = QString("Capture exposure = %1 sec, type = %2").arg(getCoreProperty(SJ_Exposure).toDouble()).arg(
                            CCDFrameTypeNames[getFrameType()]);
     logentry.append(QString(", filter = %1, upload mode = %2").arg(getCoreProperty(SJ_Filter).toString()).arg(getUploadMode()));
 
-    devices.data()->getActiveChip()->setBatchMode(jobType() != SequenceJob::JOBTYPE_PREVIEW);
-    devices.data()->getActiveCamera()->setSeqPrefix(getCoreProperty(SJ_FullPrefix).toString());
-    logentry.append(QString(", batch mode = %1, seq prefix = %2").arg(jobType() != SequenceJob::JOBTYPE_PREVIEW ? "true" :
-                    "false").arg(getCoreProperty(SJ_FullPrefix).toString()));
-
-    if (jobType() == SequenceJob::JOBTYPE_PREVIEW)
-    {
-        if (devices.data()->getActiveCamera()->getUploadMode() != ISD::Camera::UPLOAD_CLIENT)
-            devices.data()->getActiveCamera()->setUploadMode(ISD::Camera::UPLOAD_CLIENT);
-    }
-    else
-        devices.data()->getActiveCamera()->setUploadMode(m_UploadMode);
 
     QMapIterator<QString, QMap<QString, QVariant>> i(m_CustomProperties);
     while (i.hasNext())
@@ -281,16 +274,6 @@ void SequenceJob::capture(FITSMode mode)
         }
     }
 
-    const auto remoteFormatDirectory = getCoreProperty(SJ_RemoteFormatDirectory).toString();
-    const auto remoteFormatFilename = getCoreProperty(SJ_RemoteFormatFilename).toString();
-    if (devices.data()->getActiveChip()->isBatchMode() &&
-            remoteFormatDirectory.isEmpty() == false &&
-            remoteFormatFilename.isEmpty() == false)
-    {
-        devices.data()->getActiveCamera()->updateUploadSettings(remoteFormatDirectory, remoteFormatFilename);
-        if (getUploadMode() != ISD::Camera::UPLOAD_CLIENT)
-            logentry.append(QString(", remote dir = %1, remote format = %2").arg(remoteFormatDirectory).arg(remoteFormatFilename));
-    }
 
     const int ISOIndex = getCoreProperty(SJ_ISOIndex).toInt();
     if (ISOIndex != -1)
@@ -314,9 +297,51 @@ void SequenceJob::capture(FITSMode mode)
         devices.data()->getActiveCamera()->setOffset(offset);
     }
 
-    devices.data()->getActiveCamera()->setCaptureFormat(getCoreProperty(SJ_Format).toString());
-    devices.data()->getActiveCamera()->setEncodingFormat(getCoreProperty(SJ_Encoding).toString());
-    devices.data()->getActiveChip()->setFrameType(getFrameType());
+    const auto remoteFormatDirectory = getCoreProperty(SJ_RemoteFormatDirectory).toString();
+    const auto remoteFormatFilename = getCoreProperty(SJ_RemoteFormatFilename).toString();
+
+    if (jobType() == SequenceJob::JOBTYPE_PREVIEW && !isVideo())
+    {
+        if (devices.data()->getActiveCamera()->getUploadMode() != ISD::Camera::UPLOAD_CLIENT)
+            devices.data()->getActiveCamera()->setUploadMode(ISD::Camera::UPLOAD_CLIENT);
+    }
+    else
+        devices.data()->getActiveCamera()->setUploadMode(m_UploadMode);
+
+    if (devices.data()->getActiveChip()->isBatchMode() &&
+            remoteFormatDirectory.isEmpty() == false &&
+            remoteFormatFilename.isEmpty() == false)
+    {
+        if (isVideo())
+            devices.data()->getActiveCamera()->setSERNameDirectory(remoteFormatFilename, remoteFormatDirectory);
+        else
+            devices.data()->getActiveCamera()->updateUploadSettings(remoteFormatDirectory, remoteFormatFilename);
+
+    }
+
+    if (isVideo())
+    {
+        // video settings
+        devices.data()->getActiveCamera()->setUploadMode(m_UploadMode);
+
+        devices.data()->getActiveCamera()->setStreamRecording(getCoreProperty(SJ_Format).toString());
+        devices.data()->getActiveCamera()->setStreamEncoding(getCoreProperty(SJ_Encoding).toString());
+    }
+    else
+    {
+        devices.data()->getActiveChip()->setBatchMode(jobType() != SequenceJob::JOBTYPE_PREVIEW);
+        devices.data()->getActiveCamera()->setSeqPrefix(getCoreProperty(SJ_FullPrefix).toString());
+        logentry.append(QString(", batch mode = %1, seq prefix = %2").arg(jobType() != SequenceJob::JOBTYPE_PREVIEW ? "true" :
+                        "false").arg(getCoreProperty(SJ_FullPrefix).toString()));
+
+
+        devices.data()->getActiveCamera()->setCaptureFormat(getCoreProperty(SJ_Format).toString());
+        devices.data()->getActiveCamera()->setEncodingFormat(getCoreProperty(SJ_Encoding).toString());
+        devices.data()->getActiveChip()->setFrameType(getFrameType());
+    }
+    if (getUploadMode() != ISD::Camera::UPLOAD_CLIENT)
+        logentry.append(QString(", remote dir = %1, remote format = %2").arg(remoteFormatDirectory).arg(remoteFormatFilename));
+
     logentry.append(QString(", format = %1, encoding = %2").arg(getCoreProperty(SJ_Format).toString()).arg(getCoreProperty(
                         SJ_Encoding).toString()));
 
@@ -364,23 +389,50 @@ void SequenceJob::capture(FITSMode mode)
     else
         logentry.append(", Cannot subframe");
 
-    // In case FITS Viewer is not enabled. Then for flat frames, we still need to keep the data
-    // otherwise INDI CCD would simply discard loading the data in batch mode as the data are already
-    // saved to disk and since no extra processing is required, FITSData is not loaded up with the data.
-    // But in case of automatically calculated flat frames, we need FITSData.
-    // Therefore, we need to explicitly set mode to FITS_CALIBRATE so that FITSData is generated.
-    devices.data()->getActiveChip()->setCaptureMode(mode);
-    devices.data()->getActiveChip()->setCaptureFilter(FITS_NONE);
+    return logentry;
+}
 
+void SequenceJob::capture(FITSMode mode)
+{
+    if (!devices.data()->getActiveCamera() || !devices.data()->getActiveChip())
+        return;
+
+    QString logentry = setCameraDeviceProperties();
+
+    // update the status
     setStatus(getStatus());
 
-    const auto exposure = getCoreProperty(SJ_Exposure).toDouble();
-    m_ExposeLeft = exposure;
-    devices.data()->getActiveChip()->capture(exposure);
-    // create log entry with settings
-    qCInfo(KSTARS_EKOS_CAPTURE()) << logentry;
+    if (isVideo())
+    {
+        devices.data()->getActiveCamera()->setStreamExposure(getCoreProperty(SJ_Exposure).toDouble());
+        auto frames = getCoreProperty(SJ_Count).toUInt();
+        auto success = devices.data()->getActiveCamera()->startFramesRecording(frames);
+        if (! success)
+        {
+            qCWarning(KSTARS_EKOS_CAPTURE) << "Start recording failed!";
+            emit captureStarted(CAPTURE_FRAME_ERROR);
+            return;
+        }
+
+    }
+    else
+    {
+        // In case FITS Viewer is not enabled. Then for flat frames, we still need to keep the data
+        // otherwise INDI CCD would simply discard loading the data in batch mode as the data are already
+        // saved to disk and since no extra processing is required, FITSData is not loaded up with the data.
+        // But in case of automatically calculated flat frames, we need FITSData.
+        // Therefore, we need to explicitly set mode to FITS_CALIBRATE so that FITSData is generated.
+        devices.data()->getActiveChip()->setCaptureMode(mode);
+        devices.data()->getActiveChip()->setCaptureFilter(FITS_NONE);
+
+        m_ExposeLeft = getCoreProperty(SJ_Exposure).toDouble();
+        devices.data()->getActiveChip()->capture(m_ExposeLeft);
+    }
 
     emit captureStarted(CAPTURE_OK);
+
+    // create log entry with settings
+    qCInfo(KSTARS_EKOS_CAPTURE) << logentry;
 }
 
 void SequenceJob::setTargetFilter(int pos, const QString &name)
@@ -523,6 +575,7 @@ void SequenceJob::prepareCapture()
     switch (getFrameType())
     {
         case FRAME_LIGHT:
+        case FRAME_VIDEO:
             state->prepareLightFrameCapture(getCoreProperty(SJ_EnforceTemperature).toBool(),
                                             jobType() == SequenceJob::JOBTYPE_PREVIEW);
             break;
@@ -605,6 +658,7 @@ void SequenceJob::loadFrom(XMLEle *root, const QString &targetName, SequenceJobT
     m_CoreProperties[SJ_ROI] = QRect(0, 0, 0, 0);
     m_CoreProperties[SJ_EnforceTemperature] = false;
     m_CoreProperties[SJ_GuiderActive] = false;
+    m_CoreProperties[SJ_DitherPerJobEnabled] = true;
     m_CoreProperties[SJ_DitherPerJobFrequency] = 0;
     m_CoreProperties[SJ_Encoding] = "FITS";
 
@@ -683,29 +737,30 @@ void SequenceJob::loadFrom(XMLEle *root, const QString &targetName, SequenceJobT
         }
         else if (!strcmp(tagXMLEle(ep), "TargetName"))
         {
-            auto jobTarget = pcdataXMLEle(ep);
+            QString jobTarget = pcdataXMLEle(ep);
 
-            if (targetName == "")
+            if (targetName.isEmpty())
                 // use the target from the XML document
                 setCoreProperty(SequenceJob::SJ_TargetName, QString(jobTarget));
-            else if (strcmp(jobTarget, "") != 0)
+            else if (!jobTarget.isEmpty())
                 // issue a warning that target from the XML document is ignored
-                qWarning(KSTARS_EKOS_CAPTURE) << QString("Sequence job target name %1 ignored.").arg(jobTarget);
+                qWarning(KSTARS_EKOS_CAPTURE) << QString("Sequence job target name %1 ignored in favor of %2.").arg(jobTarget, targetName);
         }
         else if (!strcmp(tagXMLEle(ep), "Prefix"))
         {
+            qWarning(KSTARS_EKOS_CAPTURE) << QString("Sequence job is using outdated format. Please create a new sequence file");
             // RawPrefix is outdated and will be ignored
             subEP = findXMLEle(ep, "RawPrefix");
             if (subEP)
             {
-                auto jobTarget = pcdataXMLEle(subEP);
+                QString jobTarget = pcdataXMLEle(subEP);
 
-                if (targetName == "")
+                if (targetName.isEmpty())
                     // use the target from the XML document
                     setCoreProperty(SequenceJob::SJ_TargetName, QString(jobTarget));
-                else if (strcmp(jobTarget, "") != 0)
+                else if (!jobTarget.isEmpty())
                     // issue a warning that target from the XML document is ignored
-                    qWarning(KSTARS_EKOS_CAPTURE) << QString("Sequence job raw prefix %1 ignored.").arg(jobTarget);
+                    qWarning(KSTARS_EKOS_CAPTURE) << QString("Sequence job target name %1 ignored in favor of %2.").arg(jobTarget, targetName);
             }
             bool filterEnabled = false, expEnabled = false, tsEnabled = false;
             subEP = findXMLEle(ep, "FilterEnabled");
@@ -747,7 +802,14 @@ void SequenceJob::loadFrom(XMLEle *root, const QString &targetName, SequenceJobT
         }
         else if (!strcmp(tagXMLEle(ep), "GuideDitherPerJob"))
         {
-            setCoreProperty(SequenceJob::SJ_DitherPerJobFrequency, cLocale.toInt(pcdataXMLEle(ep)));
+            const int value = cLocale.toInt(pcdataXMLEle(ep));
+            if (value >= 0)
+            {
+                setCoreProperty(SequenceJob::SJ_DitherPerJobFrequency, value);
+                setCoreProperty(SequenceJob::SJ_DitherPerJobEnabled, true);
+            }
+            else
+                setCoreProperty(SequenceJob::SJ_DitherPerJobEnabled, false);
         }
         else if (!strcmp(tagXMLEle(ep), "FITSDirectory"))
         {
@@ -916,6 +978,8 @@ void SequenceJob::loadFrom(XMLEle *root, const QString &targetName, SequenceJobT
 void SequenceJob::saveTo(QTextStream &outstream, const QLocale &cLocale) const
 {
     auto roi = getCoreProperty(SequenceJob::SJ_ROI).toRect();
+    auto ditherPerJobEnabled = getCoreProperty(SequenceJob::SJ_DitherPerJobEnabled).toBool();
+    auto ditherPerJobFrequency = getCoreProperty(SequenceJob::SJ_DitherPerJobFrequency).toInt();
 
     outstream << "<Job>" << Qt::endl;
 
@@ -955,7 +1019,7 @@ void SequenceJob::saveTo(QTextStream &outstream, const QLocale &cLocale) const
     if (getScript(SCRIPT_POST_JOB).isEmpty() == false)
         outstream << "<PostJobScript>" << getScript(SCRIPT_POST_JOB) << "</PostJobScript>" << Qt::endl;
     outstream << "<GuideDitherPerJob>"
-              << cLocale.toString(getCoreProperty(SequenceJob::SJ_DitherPerJobFrequency).toInt()) << "</GuideDitherPerJob>" <<
+              << cLocale.toString(ditherPerJobEnabled ? ditherPerJobFrequency : -1) << "</GuideDitherPerJob>" <<
               Qt::endl;
     outstream << "<FITSDirectory>" << getCoreProperty(SequenceJob::SJ_LocalDirectory).toString() << "</FITSDirectory>" <<
               Qt::endl;
