@@ -17,13 +17,18 @@
 #include <config-kstars.h>
 
 #ifdef HAVE_KEYCHAIN
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+#include <qt6keychain/keychain.h>
+#else
 #include <qt5keychain/keychain.h>
 #endif
+#endif
 
 #include <QJsonDocument>
 #include <QJsonObject>
 #include <QNetworkAccessManager>
 #include <QNetworkReply>
+#include <QFormLayout>
 
 namespace EkosLive
 {
