@@ -53,15 +53,6 @@ class StellarSolverProfileEditor;
 class Focus : public QWidget, public Ui::Focus
 {
         Q_OBJECT
-        Q_CLASSINFO("D-Bus Interface", "org.kde.kstars.Ekos.Focus")
-        Q_PROPERTY(Ekos::FocusState status READ status NOTIFY newStatus)
-        Q_PROPERTY(QString opticalTrain READ opticalTrain WRITE setOpticalTrain)
-        Q_PROPERTY(QString camera READ camera)
-        Q_PROPERTY(QString focuser READ focuser)
-        Q_PROPERTY(QString filterWheel READ filterWheel)
-        Q_PROPERTY(QString filter READ filter WRITE setFilter)
-        Q_PROPERTY(double HFR READ getHFR NOTIFY newHFR)
-        Q_PROPERTY(double exposure READ exposure WRITE setExposure)
 
         // AdaptiveFocus and FocusAdvisor are friend classes so they can access methods in Focus
         friend class AdaptiveFocus;
@@ -125,6 +116,14 @@ class Focus : public QWidget, public Ui::Focus
             return (m_FocusType == FOCUS_AUTO);
         }
 
+        /** DBUS interface function.
+         * @return Returns True if current focuser uses the full field for focusing
+         */
+        Q_SCRIPTABLE bool useFullField()
+        {
+            return m_OpsFocusSettings->focusUseFullField->isChecked();
+        }
+
         /** DBUS interface function.
              * @return Returns Half-Flux-Radius in pixels.
              */
@@ -276,18 +275,20 @@ public slots:
         /** DBUS interface function.
              * Focus inward
              * @param ms If set, focus inward for ms ticks (Absolute Focuser), or ms milliseconds (Relative Focuser). If not set, it will use the value specified in the options.
+             * @param speedFactor option to multiply the given ms value for faster motion
              */
-        Q_SCRIPTABLE bool focusIn(int ms = -1);
+        Q_SCRIPTABLE bool focusIn(int ms = -1, int speedFactor = 1);
 
         /** DBUS interface function.
              * Focus outward
              * @param ms If set, focus outward for ms ticks (Absolute Focuser), or ms milliseconds (Relative Focuser). If not set, it will use the value specified in the options.
              */
-        Q_SCRIPTABLE bool focusOut(int ms = -1);
+        Q_SCRIPTABLE bool focusOut(int ms = -1, int speedFactor = 1);
 
         /**
              * @brief checkFocus Given the minimum required HFR, check focus and calculate HFR. If current HFR exceeds required HFR, start autofocus process, otherwise do nothing.
              * @param requiredHFR Minimum HFR to trigger autofocus process.
+             * @param speedFactor option to multiply the given ms value for faster motion
              */
         Q_SCRIPTABLE Q_NOREPLY void checkFocus(double requiredHFR);
 
@@ -487,7 +488,7 @@ public slots:
     signals:
         void newLog(const QString &text);
         void newFocusLog(const QString &text);
-        void newStatus(Ekos::FocusState state, const QString &trainname);
+        void newStatus(Ekos::FocusState state, const QString &trainname, const bool update = true);
         void newHFR(double hfr, int position, bool inAutofocus, const QString &trainname);
         void newFocusTemperatureDelta(double delta, double absTemperature, const QString &trainname);
         void inSequenceAF(bool requested, const QString &trainname);
@@ -495,6 +496,7 @@ public slots:
         void absolutePositionChanged(int value);
         void focusPositionAdjusted();
         void focusAdaptiveComplete(bool success, const QString &trainname);
+        void focusAFOptimise();
 
         void trainChanged();
         void focuserChanged(int id, bool isValid);
@@ -711,6 +713,9 @@ public slots:
         void autoFocusLinear();
         void autoFocusRel();
 
+        // events
+        void handleFocusButtonEvent();
+
         // Linear does plotting differently from the rest.
         void plotLinearFocus();
 
@@ -732,6 +737,11 @@ public slots:
         }
         void resetButtons();
 
+        /**
+         * @brief updateButtonColors Change button colors due Shift and Ctrl modifiers
+         */
+        void updateButtonColors(QPushButton *button, bool shift, bool ctrl);
+
         /**
          * @brief returns whether the Aberration Inspector can be used or not
          * @return can / cant be started
@@ -864,7 +874,8 @@ public slots:
         void resetAdaptiveFocus(bool enabled);
 
         void setupOpticalTrainManager();
-        void refreshOpticalTrain();
+        void initOpticalTrain();
+        void refreshOpticalTrain(const int id);
 
         /**
          * @brief set member valiables for the scope attached to the current Optical Train
@@ -949,6 +960,13 @@ public slots:
          */
         void donutTimeDilation();
 
+        /**
+         * @brief Filter out duplicate Autofocus requests
+         * @param autofocusReason reason for running this Autofocus
+         * @return true means do not run AF (previous run only just completed)
+         */
+        bool checkAFOptimisation(const AutofocusReason autofocusReason);
+
         /// Focuser device needed for focus operation
         ISD::Focuser *m_Focuser { nullptr };
         int m_focuserId;
@@ -1084,6 +1102,8 @@ public slots:
         bool inAdjustFocus { false };
         /// Build offsets is a special case of the Autofocus run
         bool inBuildOffsets { false };
+        /// AF Optimise is a special case of the Autofocus run
+        bool inAFOptimise { false };
         // Target frame dimensions
         //int fx,fy,fw,fh;
         /// If HFR=-1 which means no stars detected, we need to decide how many times should the re-capture process take place before we give up or reverse direction.
@@ -1099,7 +1119,7 @@ public slots:
         // R2 as a measure of how well the curve fits the datapoints. Passed to the V-curve graph for display
         double R2 = 0;
         // Counter to retry the auto focus run if the R2Limit has not been reached
-        int R2Retries = 0;
+        int m_R2Retries = 0;
         // Counter to retry starting focus operation (autofocus, adjust focus, etc) if the focuser is still active
         int m_StartRetries = 0;
         // Reason code for the Autofocus run - passed to Analyze
@@ -1145,7 +1165,7 @@ public slots:
         {
             return m_state;
         }
-        void setState(FocusState newState);
+        void setState(FocusState newState, const bool update = true);
 
         bool isBusy()
         {
