@@ -37,7 +37,7 @@ OpsGuide::OpsGuide() : QFrame(KStars::Instance())
     {
         KConfigDialog *optionsEditor = new KConfigDialog(this, "OptionsProfileEditor", Options::self());
         optionsProfileEditor = new StellarSolverProfileEditor(this, Ekos::GuideProfiles, optionsEditor);
-#ifdef Q_OS_OSX
+#ifdef Q_OS_MACOS
         optionsEditor->setWindowFlags(Qt::Tool | Qt::WindowStaysOnTopHint);
 #endif
         KPageWidgetItem *mainPage = optionsEditor->addPage(optionsProfileEditor, i18n("Guide Options Profile Editor"));
@@ -49,7 +49,7 @@ OpsGuide::OpsGuide() : QFrame(KStars::Instance())
 
     loadOptionsProfiles();
 
-    connect(m_ConfigDialog, SIGNAL(settingsChanged(QString)), this, SIGNAL(settingsUpdated()));
+    connect(m_ConfigDialog, &KConfigDialog::settingsChanged, this, &OpsGuide::settingsUpdated);
 
 }
 
