@@ -124,6 +124,12 @@ public:
      */
     bool shouldSchedulerSleep(SchedulerJob *job);
 
+    /**
+     * @brief mountCoords read the equatorial coordinates from the mount
+     * @return {RA, DEC}
+     */
+    SkyPoint mountCoords();
+
     /**
      * @brief startSlew DBus call for initiating slew
      */
@@ -744,6 +750,10 @@ private:
      */
     void checkDomeParkingStatus();
 
+    /**
+     * @brief startFocusing Start focusing on the job
+     */
+    void startFocusing(SchedulerJob *job);
     // ////////////////////////////////////////////////////////////////////
     // device handling
     // ////////////////////////////////////////////////////////////////////
