@@ -27,13 +27,13 @@ SchedulerJob *SchedulerUtils::createJob(XMLEle *root, SchedulerJob *leadJob)
     QString name, group, train;
     bool isLead = true;
     dms ra, dec;
-    double rotation = 0.0, minimumAltitude = 0.0, minimumMoonSeparation = 0.0;
+    double rotation = 0.0, minimumAltitude = 0.0, minimumMoonSeparation = -1, maxMoonAltitude = 90.0;
     QUrl sequenceURL, fitsURL;
     StartupCondition startup = START_ASAP;
     CompletionCondition completion = FINISH_SEQUENCE;
     QDateTime startupTime, completionTime;
     int completionRepeats = 0;
-    bool enforceWeather = false, enforceTwilight = false, enforceArtificialHorizon = false,
+    bool enforceTwilight = false, enforceArtificialHorizon = false,
          track = false, focus = false, align = false, guide = false;
 
 
@@ -105,8 +105,11 @@ SchedulerJob *SchedulerUtils::createJob(XMLEle *root, SchedulerJob *leadJob)
                     Options::setSchedulerMoonSeparation(true);
                     minimumMoonSeparation = cLocale.toDouble(findXMLAttValu(subEP, "value"));
                 }
-                else if (!strcmp("EnforceWeather", pcdataXMLEle(subEP)))
-                    enforceWeather = true;
+                else if (!strcmp("MoonMaxAltitude", pcdataXMLEle(subEP)))
+                {
+                    Options::setSchedulerMoonAltitude(true);
+                    maxMoonAltitude = cLocale.toDouble(findXMLAttValu(subEP, "value"));
+                }
                 else if (!strcmp("EnforceTwilight", pcdataXMLEle(subEP)))
                     enforceTwilight = true;
                 else if (!strcmp("EnforceArtificialHorizon", pcdataXMLEle(subEP)))
@@ -161,7 +164,7 @@ SchedulerJob *SchedulerUtils::createJob(XMLEle *root, SchedulerJob *leadJob)
 
                              minimumAltitude,
                              minimumMoonSeparation,
-                             enforceWeather,
+                             maxMoonAltitude,
                              enforceTwilight,
                              enforceArtificialHorizon,
 
@@ -177,7 +180,8 @@ void SchedulerUtils::setupJob(SchedulerJob &job, const QString &name, bool isLea
                               const QString &train, const dms &ra, const dms &dec, double djd, double rotation, const QUrl &sequenceUrl,
                               const QUrl &fitsUrl, StartupCondition startup, const QDateTime &startupTime, CompletionCondition completion,
                               const QDateTime &completionTime, int completionRepeats, double minimumAltitude, double minimumMoonSeparation,
-                              bool enforceWeather, bool enforceTwilight, bool enforceArtificialHorizon, bool track, bool focus, bool align, bool guide)
+                              double maxMoonAltitude, bool enforceTwilight, bool enforceArtificialHorizon, bool track, bool focus,
+                              bool align, bool guide)
 {
     /* Configure or reconfigure the observation job */
 
@@ -205,12 +209,11 @@ void SchedulerUtils::setupJob(SchedulerJob &job, const QString &name, bool isLea
         job.setStartAtTime(job.getStartupTime());
 
         // #2 Constraints
-
         job.setMinAltitude(minimumAltitude);
         job.setMinMoonSeparation(minimumMoonSeparation);
+        job.setMaxMoonAltitude(maxMoonAltitude);
 
         // Check enforce weather constraints
-        job.setEnforceWeather(enforceWeather);
         // twilight constraints
         job.setEnforceTwilight(enforceTwilight);
         job.setEnforceArtificialHorizon(enforceArtificialHorizon);
@@ -311,7 +314,7 @@ uint16_t SchedulerUtils::fillCapturedFramesMap(const CapturedFramesMap &expected
     return totalCompletedCount;
 }
 
-void SchedulerUtils::updateLightFramesRequired(SchedulerJob * oneJob, const QList<SequenceJob *> &seqjobs,
+void SchedulerUtils::updateLightFramesRequired(SchedulerJob * oneJob, const QList<QSharedPointer<SequenceJob> > &seqjobs,
         const CapturedFramesMap &framesCount)
 {
     bool lightFramesRequired = false;
@@ -323,7 +326,7 @@ void SchedulerUtils::updateLightFramesRequired(SchedulerJob * oneJob, const QLis
             // Step 1: determine expected frames
             SchedulerUtils::calculateExpectedCapturesMap(seqjobs, expected);
             // Step 2: compare with already captured frames
-            for (SequenceJob *oneSeqJob : seqjobs)
+            for (auto oneSeqJob : seqjobs)
             {
                 QString const signature = oneSeqJob->getSignature();
                 /* If frame is LIGHT, how many do we have left? */
@@ -342,9 +345,9 @@ void SchedulerUtils::updateLightFramesRequired(SchedulerJob * oneJob, const QLis
     oneJob->setLightFramesRequired(lightFramesRequired);
 }
 
-SequenceJob *SchedulerUtils::processSequenceJobInfo(XMLEle * root, SchedulerJob * schedJob)
+QSharedPointer<SequenceJob> SchedulerUtils::processSequenceJobInfo(XMLEle * root, SchedulerJob * schedJob)
 {
-    SequenceJob *job = new SequenceJob(root, schedJob->getName());
+    QSharedPointer<SequenceJob> job = QSharedPointer<SequenceJob>(new SequenceJob(root, schedJob->getName()));
     if (schedJob)
     {
         if (FRAME_LIGHT == job->getFrameType())
@@ -354,13 +357,13 @@ SequenceJob *SchedulerUtils::processSequenceJobInfo(XMLEle * root, SchedulerJob
     }
 
     auto placeholderPath = Ekos::PlaceholderPath();
-    placeholderPath.processJobInfo(job);
+    placeholderPath.processJobInfo(job.get());
 
     return job;
 }
 
-bool SchedulerUtils::loadSequenceQueue(const QString &fileURL, SchedulerJob * schedJob, QList<SequenceJob *> &jobs,
-                                       bool &hasAutoFocus, ModuleLogger * logger)
+bool SchedulerUtils::loadSequenceQueue(const QString &fileURL, SchedulerJob *schedJob,
+                                       QList<QSharedPointer<SequenceJob>> &jobs, bool &hasAutoFocus, ModuleLogger * logger)
 {
     QFile sFile;
     sFile.setFileName(fileURL);
@@ -389,7 +392,7 @@ bool SchedulerUtils::loadSequenceQueue(const QString &fileURL, SchedulerJob * sc
                     hasAutoFocus = (!strcmp(findXMLAttValu(ep, "enabled"), "true"));
                 else if (!strcmp(tagXMLEle(ep), "Job"))
                 {
-                    SequenceJob *thisJob = processSequenceJobInfo(ep, schedJob);
+                    QSharedPointer<SequenceJob> thisJob = processSequenceJobInfo(ep, schedJob);
                     jobs.append(thisJob);
                     if (jobs.count() == 1)
                     {
@@ -408,7 +411,6 @@ bool SchedulerUtils::loadSequenceQueue(const QString &fileURL, SchedulerJob * sc
         {
             if (logger != nullptr) logger->appendLogText(QString(errmsg));
             delLilXML(xmlParser);
-            qDeleteAll(jobs);
             return false;
         }
     }
@@ -422,7 +424,7 @@ bool SchedulerUtils::estimateJobTime(SchedulerJob * schedJob, const CapturedFram
     static SchedulerJob *jobWarned = nullptr;
 
     // Load the sequence job associated with the argument scheduler job.
-    QList<SequenceJob *> seqJobs;
+    QList<QSharedPointer<SequenceJob>> seqJobs;
     bool hasAutoFocus = false;
     bool result = loadSequenceQueue(schedJob->getSequenceFile().toLocalFile(), schedJob, seqJobs, hasAutoFocus, logger);
     if (result == false)
@@ -465,7 +467,7 @@ bool SchedulerUtils::estimateJobTime(SchedulerJob * schedJob, const CapturedFram
                                    completedIterations);
     schedJob->setCompletedIterations(completedIterations);
     // Loop through sequence jobs to calculate the number of required frames and estimate duration.
-    foreach (SequenceJob *seqJob, seqJobs)
+    foreach (auto seqJob, seqJobs)
     {
         // FIXME: find a way to actually display the filter name.
         QString seqName = i18n("Job '%1' %2x%3\" %4", schedJob->getName(), seqJob->getCoreProperty(SequenceJob::SJ_Count).toInt(),
@@ -477,7 +479,6 @@ bool SchedulerUtils::estimateJobTime(SchedulerJob * schedJob, const CapturedFram
             qCInfo(KSTARS_EKOS_SCHEDULER) <<
                                           QString("%1 duration cannot be estimated time since the sequence saves the files remotely.").arg(seqName);
             schedJob->setEstimatedTime(-2);
-            qDeleteAll(seqJobs);
             return true;
         }
 
@@ -530,7 +531,7 @@ bool SchedulerUtils::estimateJobTime(SchedulerJob * schedJob, const CapturedFram
                                               captures_completed).arg(QFileInfo(signature).path());
 
             // Enumerate sequence jobs to check how many captures are completed overall in the same storage as the current one
-            foreach (SequenceJob *prevSeqJob, seqJobs)
+            foreach (auto prevSeqJob, seqJobs)
             {
                 // Enumerate seqJobs up to the current one
                 if (seqJob == prevSeqJob)
@@ -622,8 +623,6 @@ bool SchedulerUtils::estimateJobTime(SchedulerJob * schedJob, const CapturedFram
     if (rememberJobProgress)
         schedJob->setCompletedCount(totalCompletedCount);
 
-    qDeleteAll(seqJobs);
-
     schedJob->setEstimatedTimePerRepeat(imagingTimePerRepeat);
     schedJob->setEstimatedTimeLeftThisRepeat(imagingTimeLeftThisRepeat);
     if (schedJob->getLightFramesRequired())
@@ -726,7 +725,7 @@ int SchedulerUtils::timeHeuristics(const SchedulerJob * schedJob)
 
 }
 
-uint16_t SchedulerUtils::calculateExpectedCapturesMap(const QList<SequenceJob *> &seqJobs,
+uint16_t SchedulerUtils::calculateExpectedCapturesMap(const QList<QSharedPointer<SequenceJob>> &seqJobs,
         CapturedFramesMap &expected)
 {
     uint16_t capturesPerRepeat = 0;
