@@ -408,6 +408,7 @@ bool CameraChip::capture(double exposure)
 
 bool CameraChip::abortExposure()
 {
+    if (!m_Camera) return false;
     ISwitchVectorProperty *abortProp = nullptr;
 
     switch (m_Type)
@@ -437,16 +438,17 @@ bool CameraChip::abortExposure()
 }
 bool CameraChip::canBin() const
 {
-    return CanBin;
+    return CanBin && m_Camera->getEncodingFormat() != QLatin1String("Native");
 }
 
 void CameraChip::setCanBin(bool value)
 {
     CanBin = value;
 }
+
 bool CameraChip::canSubframe() const
 {
-    return CanSubframe;
+    return CanSubframe && m_Camera->getEncodingFormat() != QLatin1String("Native");
 }
 
 void CameraChip::setCanSubframe(bool value)
@@ -523,6 +525,7 @@ QStringList CameraChip::getISOList() const
 
 bool CameraChip::isCapturing()
 {
+    if (!m_Camera) return false;
     INumberVectorProperty *expProp = nullptr;
 
     switch (m_Type)
