@@ -78,9 +78,9 @@ StreamWG::StreamWG(ISD::Camera *ccd) : QDialog(KStars::Instance())
 
     collimationOptionsB->setIcon(QIcon::fromTheme("run-build-prune"));
     connect(collimationOptionsB, &QPushButton::clicked, this, [this]()
-            {
-                CollimationOverlayOptions::Instance(this)->openEditor();
-            });
+    {
+        CollimationOverlayOptions::Instance(this)->openEditor();
+    });
 
     collimationB->setIcon(QIcon::fromTheme("crosshairs"));
     connect(CollimationOverlayOptions::Instance(this), SIGNAL(updated()), videoFrame, SLOT(modelChanged()));
@@ -115,12 +115,12 @@ StreamWG::StreamWG(ISD::Camera *ccd) : QDialog(KStars::Instance())
     optionsB->setIcon(QIcon::fromTheme("run-build"));
     resetFrameB->setIcon(QIcon::fromTheme("view-restore"));
 
-    connect(resetFrameB, SIGNAL(clicked()), this, SLOT(resetFrame()));
+    connect(resetFrameB, &QPushButton::clicked, this, &StreamWG::resetFrame);
 
     recordB->setIcon(recordIcon);
 
-    connect(recordB, SIGNAL(clicked()), this, SLOT(toggleRecord()));
-    connect(ccd, SIGNAL(videoRecordToggled(bool)), this, SLOT(updateRecordStatus(bool)));
+    connect(recordB, &QPushButton::clicked, this, &StreamWG::toggleRecord);
+    connect(ccd, &ISD::Camera::videoRecordToggled, this, &StreamWG::updateRecordStatus);
 
     connect(videoFrame, &VideoWG::newSelection, this, &StreamWG::setStreamingFrame);
     connect(videoFrame, &VideoWG::imageChanged, this, &StreamWG::imageChanged);
@@ -144,7 +144,7 @@ StreamWG::StreamWG(ISD::Camera *ccd) : QDialog(KStars::Instance())
             WESlider->setEnabled(true);
             // Set it twice!
             m_Camera->sendNewProperty(tvp);
-            QTimer::singleShot(1000, this, [ &, tvp]()
+            QTimer::singleShot(DELAY, this, [ &, tvp]()
             {
                 m_Camera->sendNewProperty(tvp);
             });
@@ -192,10 +192,10 @@ StreamWG::StreamWG(ISD::Camera *ccd) : QDialog(KStars::Instance())
     {
         if (m_Camera)
         {
-            m_Camera->setStreamExposure(targetFrameDurationSpin->value());
             m_Camera->setVideoStreamEnabled(false);
-            QTimer::singleShot(1000, this, [&]()
+            QTimer::singleShot(DELAY, this, [&]()
             {
+                m_Camera->setStreamExposure(targetFrameDurationSpin->value());
                 m_Camera->setVideoStreamEnabled(true);
             });
         }
@@ -406,7 +406,19 @@ void StreamWG::newFrame(INDI::Property prop)
 
 void StreamWG::resetFrame()
 {
-    m_Camera->resetStreamingFrame();
+    double exposure = 0;
+    if (m_Camera->getStreamExposure(&exposure))
+    {
+        m_Camera->setVideoStreamEnabled(false);
+        QTimer::singleShot(DELAY, this, [ &, exposure]()
+        {
+            m_Camera->setStreamExposure(exposure);
+            m_Camera->getChip(ISD::CameraChip::PRIMARY_CCD)->resetFrame();
+            m_Camera->setVideoStreamEnabled(true);
+        });
+    }
+    else
+        m_Camera->resetStreamingFrame();
 }
 
 void StreamWG::setStreamingFrame(QRect newFrame)
@@ -420,14 +432,27 @@ void StreamWG::setStreamingFrame(QRect newFrame)
     if (newFrame.width() < 5 || newFrame.height() < 5)
         return;
 
-    int w = newFrame.width();
-    // Must be divisable by 4
-    while (w % 4)
-    {
-        w++;
-    }
+    // Adjust X,Y in reference to existing frame.
+    int x, y, w, h;
+    m_Camera->getChip(ISD::CameraChip::PRIMARY_CCD)->getFrame(&x, &y, &w, &h);
+    auto subX = newFrame.x() + x;
+    auto subY = newFrame.y() + y;
+    auto subW = newFrame.width();
+    auto subH = newFrame.width();
 
-    m_Camera->setStreamingFrame(newFrame.x(), newFrame.y(), w, newFrame.height());
+    double exposure = 0;
+    if (m_Camera->getStreamExposure(&exposure))
+    {
+        m_Camera->setVideoStreamEnabled(false);
+        QTimer::singleShot(DELAY, this, [ &, exposure, subX, subY, subW, subH]()
+        {
+            m_Camera->setStreamExposure(exposure);
+            m_Camera->getChip(ISD::CameraChip::PRIMARY_CCD)->setFrame(subX, subY, subW, subH);
+            m_Camera->setVideoStreamEnabled(true);
+        });
+    }
+    else
+        m_Camera->setStreamingFrame(newFrame.x(), newFrame.y(), w, newFrame.height());
 }
 
 void StreamWG::updateFPS(double instantFPS, double averageFPS)
