@@ -20,6 +20,9 @@
 #include "imageexporter.h"
 #include "kstars.h"
 #include "observinglist.h"
+#ifdef HAVE_INDI
+#include "tools/imagingplanner.h"
+#endif
 #include "skymap.h"
 #include "dialogs/detaildialog.h"
 #include "oal/execute.h"
@@ -35,6 +38,9 @@
 
 #include "kstars_debug.h"
 
+// Qt version calming
+#include <qtskipemptyparts.h>
+
 namespace
 {
 // Report fatal error during data loading to user
@@ -47,7 +53,7 @@ void fatalErrorMessage(QString fname)
                                "KStars searches for this file in following locations:\n\n\t"
                                "%2\n\n"
                                "It appears that your setup is broken.",
-                               fname, QStandardPaths::standardLocations(QStandardPaths::DataLocation).join("\n\t")),
+                               fname, QStandardPaths::standardLocations(QStandardPaths::AppDataLocation).join("\n\t")),
                           i18n("Critical File Not Found: %1", fname)); // FIXME: Must list locations depending on file type
 
     qApp->exit(1);
@@ -55,27 +61,30 @@ void fatalErrorMessage(QString fname)
 
 // Report non-fatal error during data loading to user and ask
 // whether he wants to continue.
+//
+// No remaining calls so commented out to suppress unused warning
+//
 // Calls QApplication::exit if he don't
-bool nonFatalErrorMessage(QString fname)
-{
-    qCWarning(KSTARS) << i18n( "Non-Critical File Not Found: %1", fname );
-#ifdef KSTARS_LITE
-    Q_UNUSED(fname);
-    return true;
-#else
-    int res = KMessageBox::warningContinueCancel(nullptr,
-              i18n("The file %1 could not be found. "
-                   "KStars can still run without this file. "
-                   "KStars search for this file in following locations:\n\n\t"
-                   "%2\n\n"
-                   "It appears that you setup is broken. Press Continue to run KStars without this file ",
-                   fname, QStandardPaths::standardLocations( QStandardPaths::DataLocation ).join("\n\t") ),
-              i18n( "Non-Critical File Not Found: %1", fname ));  // FIXME: Must list locations depending on file type
-    if( res != KMessageBox::Continue )
-        qApp->exit(1);
-    return res == KMessageBox::Continue;
-#endif
-}
+//bool nonFatalErrorMessage(QString fname)
+//{
+//    qCWarning(KSTARS) << i18n( "Non-Critical File Not Found: %1", fname );
+//#ifdef KSTARS_LITE
+//    Q_UNUSED(fname);
+//    return true;
+//#else
+//    int res = KMessageBox::warningContinueCancel(nullptr,
+//              i18n("The file %1 could not be found. "
+//                   "KStars can still run without this file. "
+//                   "KStars search for this file in following locations:\n\n\t"
+//                   "%2\n\n"
+//                   "It appears that you setup is broken. Press Continue to run KStars without this file ",
+//                   fname, QStandardPaths::standardLocations( QStandardPaths::AppLocalDataLocation ).join("\n\t") ),
+//              i18n( "Non-Critical File Not Found: %1", fname ));  // FIXME: Must list locations depending on file type
+//    if( res != KMessageBox::Continue )
+//        qApp->exit(1);
+//    return res == KMessageBox::Continue;
+//#endif
+//}
 }
 
 KStarsData *KStarsData::pinstance = nullptr;
@@ -155,12 +164,12 @@ bool KStarsData::initialize()
 
                 QSqlQuery query(fixcitydb);
                 if (query.exec(
-                        "alter table city add column Elevation real default -10;") ==
-                    false)
+                            "alter table city add column Elevation real default -10;") ==
+                        false)
                 {
                     emit progressText(QString("failed to add Elevation column to city "
                                               "table in mycitydb.sqlite: &1")
-                                          .arg(query.lastError().text()));
+                                      .arg(query.lastError().text()));
                 }
             }
             else
@@ -198,23 +207,36 @@ bool KStarsData::initialize()
     // if (!readURLData("image_url.dat", SkyObjectUserdata::Type::image) &&
     //     !nonFatalErrorMessage("image_url.dat"))
     //     return false;
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    QFuture<bool> future = QtConcurrent::run(&KStarsData::readURLData, this, QString("image_url.dat"),
+                           SkyObjectUserdata::Type::image);
+#else
     QtConcurrent::run(this, &KStarsData::readURLData, QString("image_url.dat"),
                       SkyObjectUserdata::Type::image);
+#endif
 
     //Load Information URLs//
     //emit progressText(i18n("Loading Information URLs"));
     // if (!readURLData("info_url.dat", SkyObjectUserdata::Type::website) &&
     //     !nonFatalErrorMessage("info_url.dat"))
     //     return false;
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    future = QtConcurrent::run(&KStarsData::readURLData, this, QString("info_url.dat"),
+                               SkyObjectUserdata::Type::website);
+#else
     QtConcurrent::run(this, &KStarsData::readURLData, QString("info_url.dat"),
                       SkyObjectUserdata::Type::website);
+#endif
 
     //#endif
     //emit progressText( i18n("Loading Variable Stars" ) );
 
 #ifndef KSTARS_LITE
-    //Initialize Observing List
+    //Initialize Observing List and imaging planner
     m_ObservingList = new ObservingList();
+#ifdef HAVE_INDI
+    m_ImagingPlanner.reset(new ImagingPlanner());
+#endif
 #endif
 
     readUserLog();
@@ -424,7 +446,7 @@ SkyObject *KStarsData::objectNamed(const QString &name)
 {
     if ((name == "star") || (name == "nothing") || name.isEmpty())
         return nullptr;
-    return skyComposite()->findByName(name);
+    return skyComposite()->findByName(name, true); // objectNamed has to do an exact match
 }
 
 bool KStarsData::readCityData()
@@ -479,7 +501,7 @@ bool KStarsData::readCityData()
 
             if (!get_query.exec("SELECT * FROM city"))
             {
-                qDebug() << get_query.lastError();
+                qDebug() << Q_FUNC_INFO << get_query.lastError();
                 return false;
             }
             while (get_query.next())
@@ -516,12 +538,12 @@ bool KStarsData::readTimeZoneRulebook()
             QString line = stream.readLine().trimmed();
             if (line.length() && !line.startsWith('#')) //ignore commented and blank lines
             {
-                QStringList fields = line.split(' ', QString::SkipEmptyParts);
+                QStringList fields = line.split(' ', Qt::SkipEmptyParts);
                 QString id         = fields[0];
-                QTime stime        = QTime(fields[3].leftRef(fields[3].indexOf(':')).toInt(),
-                                           fields[3].midRef(fields[3].indexOf(':') + 1, fields[3].length()).toInt());
-                QTime rtime        = QTime(fields[6].leftRef(fields[6].indexOf(':')).toInt(),
-                                           fields[6].midRef(fields[6].indexOf(':') + 1, fields[6].length()).toInt());
+                QTime stime        = QTime(fields[3].left(fields[3].indexOf(':')).toInt(),
+                                           fields[3].mid(fields[3].indexOf(':') + 1, fields[3].length()).toInt());
+                QTime rtime        = QTime(fields[6].left(fields[6].indexOf(':')).toInt(),
+                                           fields[6].mid(fields[6].indexOf(':') + 1, fields[6].length()).toInt());
 
                 Rulebook[id] = TimeZoneRule(fields[1], fields[2], stime, fields[4], fields[5], rtime);
             }
@@ -567,7 +589,7 @@ bool KStarsData::openUrlFile(const QString &urlfile, QFile &file)
             //Find global file(s) in findAllResources() list.
             QFileInfo fi_local(file.fileName());
 
-            QStringList flist = KSPaths::locateAll(QStandardPaths::DataLocation, urlfile);
+            QStringList flist = KSPaths::locateAll(QStandardPaths::AppDataLocation, urlfile);
 
             for (int i = 0; i < flist.size(); i++)
             {
@@ -648,7 +670,7 @@ bool KStarsData::openUrlFile(const QString &urlfile, QFile &file)
             if (KSUtils::openDataFile(file, urlfile))
             {
                 if (QLocale().language() != QLocale::English)
-                    qDebug() << "No localized URL file; using default English file.";
+                    qDebug() << Q_FUNC_INFO << "No localized URL file; using default English file.";
                 // we found urlfile, we need to copy it to locale
                 localeFile.setFileName(QDir(KSPaths::writableLocation(QStandardPaths::AppLocalDataLocation)).filePath(urlfile));
                 if (localeFile.open(QIODevice::WriteOnly))
@@ -667,7 +689,7 @@ bool KStarsData::openUrlFile(const QString &urlfile, QFile &file)
                 }
                 else
                 {
-                    qDebug() << "Failed to copy default URL file to locale folder, modifying default object links is "
+                    qDebug() << Q_FUNC_INFO << "Failed to copy default URL file to locale folder, modifying default object links is "
                              "not possible";
                 }
                 fileFound = true;
@@ -766,13 +788,13 @@ bool KStarsData::readUserLog()
 
     QMutexLocker _{ &m_user_data_mutex };
 
-    QStringRef buffer(&fullContents);
+    QString buffer(fullContents);
     const QLatin1String logStart("[KSLABEL:"), logEnd("[KSLogEnd]");
     std::size_t currentEntryIndex = 0;
     while (!buffer.isEmpty())
     {
         int startIndex, endIndex;
-        QStringRef sub, name, data;
+        QString sub, name, data;
 
         startIndex = buffer.indexOf(logStart) + logStart.size();
         if (startIndex < 0)
@@ -828,8 +850,8 @@ bool KStarsData::readUserLog()
         buffer = buffer.mid(endIndex + logEnd.size() + 1);
         currentEntryIndex += (endIndex + logEnd.size() + 1 - startIndex);
 
-        auto &data_element   = m_user_data[name.toString()];
-        data_element.userLog = data.toString();
+        auto &data_element   = m_user_data[name];
+        data_element.userLog = data;
 
     } // end while
     file.close();
@@ -911,7 +933,7 @@ bool KStarsData::executeScript(const QString &scriptname, SkyMap *map)
     QFile f(scriptname);
     if (!f.open(QIODevice::ReadOnly))
     {
-        qDebug() << "Could not open file " << f.fileName();
+        qDebug() << Q_FUNC_INFO << "Could not open file " << f.fileName();
         return false;
     }
 
@@ -953,7 +975,7 @@ bool KStarsData::executeScript(const QString &scriptname, SkyMap *map)
             QStringList fn = line.mid(i).split(' ');
 
             //DEBUG
-            //qDebug() << fn;
+            //qDebug() << Q_FUNC_INFO << fn;
 
             if (fn[0] == "lookTowards" && fn.size() >= 2)
             {
@@ -1072,7 +1094,7 @@ bool KStarsData::executeScript(const QString &scriptname, SkyMap *map)
                     }
 
                     if (!ok)
-                        qDebug() << QString("Unable to load color scheme named %1. Also tried %2.")
+                        qDebug() << Q_FUNC_INFO << QString("Unable to load color scheme named %1. Also tried %2.")
                                  .arg(csName, filename);
                 }
             }
@@ -1488,13 +1510,18 @@ void KStarsData::syncFOV()
             visibleFOVs.append(fov);
     }
     // Remove unavailable FOVs
+#if QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
     QSet<QString> names = QSet<QString>::fromList(Options::fOVNames());
+#else
+    const QStringList m_fOVNames = Options::fOVNames();
+    QSet<QString> names (m_fOVNames.begin(), m_fOVNames.end());
+#endif
     QSet<QString> all;
     foreach (FOV *fov, visibleFOVs)
     {
         all.insert(fov->name());
     }
-    Options::setFOVNames(all.intersect(names).toList());
+    Options::setFOVNames(all.intersect(names).values());
 }
 
 // FIXME: Why does KStarsData store the Execute instance??? -- asimha
@@ -1532,16 +1559,16 @@ KStarsData::addToUserData(const QString &name, const SkyObjectUserdata::LinkData
     file.setFileName(
         KSPaths::writableLocation(QStandardPaths::AppLocalDataLocation) +
         (isImage ?
-             "image_url.dat" :
-             "info_url.dat")); //determine filename in local user KDE directory tree.
+         "image_url.dat" :
+         "info_url.dat")); //determine filename in local user KDE directory tree.
 
     if (!file.open(QIODevice::ReadWrite | QIODevice::Append))
         return { false,
                  isImage ?
-                     i18n("Custom image-links file could not be opened.\nLink cannot "
-                          "be recorded for future sessions.") :
-                     i18n("Custom information-links file could not be opened.\nLink "
-                          "cannot be recorded for future sessions.") };
+                 i18n("Custom image-links file could not be opened.\nLink cannot "
+                      "be recorded for future sessions.") :
+                 i18n("Custom information-links file could not be opened.\nLink "
+                      "cannot be recorded for future sessions.") };
     else
     {
         entry = name + ':' + data.title + ':' + data.url.toString();
@@ -1554,8 +1581,8 @@ KStarsData::addToUserData(const QString &name, const SkyObjectUserdata::LinkData
 }
 
 std::pair<bool, QString> updateLocalDatabase(SkyObjectUserdata::Type type,
-                                             const QString &search_line,
-                                             const QString &replace_line)
+        const QString &search_line,
+        const QString &replace_line)
 {
     QString TempFileName, file_line;
     QFile URLFile;
@@ -1572,7 +1599,7 @@ std::pair<bool, QString> updateLocalDatabase(SkyObjectUserdata::Type type,
 
     switch (type)
     {
-            // Info Links
+        // Info Links
         case SkyObjectUserdata::Type::website:
             // Get name for our local info_url file
             URLFile.setFileName(
@@ -1580,7 +1607,7 @@ std::pair<bool, QString> updateLocalDatabase(SkyObjectUserdata::Type type,
                 "info_url.dat");
             break;
 
-            // Image Links
+        // Image Links
         case SkyObjectUserdata::Type::image:
             // Get name for our local info_url file
             URLFile.setFileName(
@@ -1597,7 +1624,7 @@ std::pair<bool, QString> updateLocalDatabase(SkyObjectUserdata::Type type,
     if (!URLFile.open(QIODevice::WriteOnly))
     {
         return { false, "Failed to open " + URLFile.fileName() +
-                            "KStars cannot save to user database" };
+                 "KStars cannot save to user database" };
     }
 
     // Get streams;
@@ -1633,8 +1660,8 @@ std::pair<bool, QString> updateLocalDatabase(SkyObjectUserdata::Type type,
 }
 
 std::pair<bool, QString> KStarsData::editUserData(const QString &name,
-                                                  const unsigned int index,
-                                                  const SkyObjectUserdata::LinkData &data)
+        const unsigned int index,
+        const SkyObjectUserdata::LinkData &data)
 {
     QMutexLocker _{ &m_user_data_mutex };
 
@@ -1655,8 +1682,8 @@ std::pair<bool, QString> KStarsData::editUserData(const QString &name,
 }
 
 std::pair<bool, QString> KStarsData::deleteUserData(const QString &name,
-                                                    const unsigned int index,
-                                                    SkyObjectUserdata::Type type)
+        const unsigned int index,
+        SkyObjectUserdata::Type type)
 {
     QMutexLocker _{ &m_user_data_mutex };
 
@@ -1678,7 +1705,7 @@ std::pair<bool, QString> KStarsData::deleteUserData(const QString &name,
 }
 
 std::pair<bool, QString> KStarsData::updateUserLog(const QString &name,
-                                                   const QString &newLog)
+        const QString &newLog)
 {
     QMutexLocker _{ &m_user_data_mutex };
 
@@ -1689,7 +1716,7 @@ std::pair<bool, QString> KStarsData::updateUserLog(const QString &name,
     //+ new log is the "default" message
     //+ new log is empty
     if (newLog == (i18n("Record here observation logs and/or data on %1.", name)) ||
-        newLog.isEmpty())
+            newLog.isEmpty())
         return { true, {} };
 
     // header label
