@@ -582,7 +582,7 @@ void SkyMap::mouseMoveEvent(QMouseEvent *e)
         return; // break if point is unusable
 
     //determine RA, Dec of mouse pointer
-    m_MousePoint = projector()->fromScreen(e->pos(), data->lst(), data->geo()->lat());
+    m_MousePoint = projector()->fromScreen(e->pos(), data);
 
     double dyPix = 0.5 * height() - e->y();
     if (midMouseButtonDown) //zoom according to y-offset
@@ -632,7 +632,7 @@ void SkyMap::mouseMoveEvent(QMouseEvent *e)
                     emit mosaicCenterChanged(dRA, dDec);
 
                     // Update mouse and clicked points.
-                    m_MousePoint = projector()->fromScreen(e->pos(), data->lst(), data->geo()->lat());
+                    m_MousePoint = projector()->fromScreen(e->pos(), data);
                     setClickedPoint(&m_MousePoint);
                     update();
                     return;
@@ -674,7 +674,7 @@ void SkyMap::mouseMoveEvent(QMouseEvent *e)
         showFocusCoords();
 
         //redetermine RA, Dec of mouse pointer, using new focus
-        m_MousePoint = projector()->fromScreen(e->pos(), data->lst(), data->geo()->lat());
+        m_MousePoint = projector()->fromScreen(e->pos(), data);
         setClickedPoint(&m_MousePoint);
         forceUpdate(); // must be new computed
     }
@@ -708,7 +708,7 @@ void SkyMap::mouseReleaseEvent(QMouseEvent *e)
     if (ZoomRect.isValid())
     {
         stopTracking();
-        SkyPoint newcenter = projector()->fromScreen(ZoomRect.center(), data->lst(), data->geo()->lat());
+        SkyPoint newcenter = projector()->fromScreen(ZoomRect.center(), data);
         setFocus(&newcenter);
         setDestination(newcenter);
 
@@ -803,7 +803,7 @@ void SkyMap::mousePressEvent(QMouseEvent *e)
         }
 
         //determine RA, Dec of mouse pointer
-        m_MousePoint = projector()->fromScreen(e->pos(), data->lst(), data->geo()->lat());
+        m_MousePoint = projector()->fromScreen(e->pos(), data);
         setClickedPoint(&m_MousePoint);
 
         //Find object nearest to clickedPoint()
