@@ -10,15 +10,16 @@
 #include "Options.h"
 
 #include <QWidget>
+#include <QDebug>
+#include <QLinearGradient>
 #include <QMouseEvent>
 #include <QPainter>
 #include <QTime>
-#include <QLinearGradient>
+#include <QToolTip>
 
 #include <KLocalizedString>
 #include <kplotobject.h>
 #include <kplotpoint.h>
-#include <QDebug>
 
 #include "kplotaxis.h"
 #include "ksalmanac.h"
@@ -35,8 +36,9 @@ void AVTPlotWidget::mousePressEvent(QMouseEvent *e)
     mouseMoveEvent(e);
 }
 
-void AVTPlotWidget::mouseDoubleClickEvent(QMouseEvent *)
+void AVTPlotWidget::mouseDoubleClickEvent(QMouseEvent *e)
 {
+    Q_UNUSED(e);
     MousePoint = QPoint(-1, -1);
     update();
 }
@@ -63,9 +65,48 @@ void AVTPlotWidget::mouseMoveEvent(QMouseEvent *e)
     Ycursor -= topPadding();
 
     MousePoint = QPoint(Xcursor, Ycursor);
+    displayToolTip(e->pos(), e->globalPos());
     update();
 }
 
+bool AVTPlotWidget::event(QEvent *event)
+{
+    if (event->type() == QEvent::ToolTip)
+    {
+        QHelpEvent *helpEvent = static_cast<QHelpEvent *>(event);
+        displayToolTip(helpEvent->pos(), helpEvent->globalPos());
+        return true;
+    }
+    return QWidget::event(event);
+}
+
+// Map logical data coordinates to mouse coordinates.
+QPointF AVTPlotWidget::toXY(double vx, double vy)
+{
+    QRectF plotArea = pixRect();
+    double px = leftPadding() + ((vx - xMin) * plotArea.width()) / (xMax - xMin);
+    // Top of the plot is y=0
+    double py = topPadding() + ((altitudeAxisMax - vy) * plotArea.height()) / (altitudeAxisMax - altitudeAxisMin);
+    return QPointF(px, py);
+}
+
+void AVTPlotWidget::displayToolTip(const QPoint &pos, const QPoint &globalPos)
+{
+    for (const auto &tip : tips)
+    {
+        for (const auto &pt : tip.points)
+        {
+            if (qAbs(pt.x() - pos.x()) < 5 && qAbs(pt.y() - pos.y()) < 5)
+            {
+                QToolTip::showText(globalPos, tip.label, this, QRect(), 3000);
+                return;
+            }
+        }
+    }
+    QToolTip::hideText();
+}
+
+
 // All the int coordinates (rise, set) need to be converted from hours relative to midnight
 // into graph coordinates before calling this.
 void drawMoon(QPainter &p, int rise, int set, int fade, const QColor &color, int width, int height, double leftPadding)
@@ -341,8 +382,8 @@ void AVTPlotWidget::paintEvent(QPaintEvent *e)
 
         double h = (MousePoint.x() * plotDuration) / pW - (12.0 - noonOffset);
         double a = 0;
-        if (plotObjects().size() > 0)
-            a = findYValue(plotObjects()[0], h);
+        if (currentLine >= 0 && currentLine < plotObjects().size())
+            a = findYValue(plotObjects()[currentLine], h);
         p.drawText(15, 15, QString::number(a, 'f', 1) + QChar(176));
 
         if (h < 0.0)
@@ -360,6 +401,12 @@ void AVTPlotWidget::paintEvent(QPaintEvent *e)
     p.end();
 }
 
+void AVTPlotWidget::setCurrentLine(int index)
+{
+    if (index >= 0 && index < plotObjects().size())
+        currentLine = index;
+}
+
 void AVTPlotWidget::setDawnDuskTimes(double da, double du)
 {
     Dawn = da;
@@ -400,42 +447,63 @@ void AVTPlotWidget::setPlotExtent(double offset, double duration)
     plotDuration = duration;
 }
 
-void AVTPlotWidget::plot(const GeoLocation *geo, KSAlmanac *ksal,
-                         const QVector<double> &times, const QVector<double> &alts, bool overlay)
+void AVTPlotWidget::disableAxis(KPlotWidget::Axis axisToDisable)
 {
-    KPlotObject *po = new KPlotObject(Qt::white, KPlotObject::Lines, 2);
-    if (overlay)
-    {
-        QPen pen;
-        pen.setWidth(5);
-        pen.setColor(Qt::green);
-        po->setLinePen(pen);
-    }
-    else
-    {
-        setLimits(times[0], times.last(), altitudeAxisMin, altitudeAxisMax);
-        setSecondaryLimits(times[0], times.last(), altitudeAxisMin, altitudeAxisMax);
-        axis(KPlotWidget::BottomAxis)->setTickLabelFormat('t');
-        axis(KPlotWidget::TopAxis)->setTickLabelFormat('t');
-        axis(KPlotWidget::TopAxis)->setTickLabelsShown(true);
-        setGeoLocation(geo);
+    axis(axisToDisable)->setVisible(false);
+}
 
-        setSunRiseSetTimes(ksal->getSunRise(), ksal->getSunSet());
-        setDawnDuskTimes(ksal->getDawnAstronomicalTwilight(), ksal->getDuskAstronomicalTwilight());
-        setMinMaxSunAlt(ksal->getSunMinAlt(), ksal->getSunMaxAlt());
-        setMoonRiseSetTimes(ksal->getMoonRise(), ksal->getMoonSet());
-        setMoonIllum(ksal->getMoonIllum());
+void AVTPlotWidget::plot(const GeoLocation *geo, KSAlmanac *ksal, const QVector<double> &times,
+                         const QVector<double> &alts, int lineWidth, Qt::GlobalColor color, const QString &label)
+{
+    currentLine = 0;
+    xMin = times[0];
+    xMax = times.last();
+    setLimits(xMin, xMax, altitudeAxisMin, altitudeAxisMax);
 
-        const double noonOffset = times[0] - -12;
-        const double plotDuration = times.last() - times[0];
-        setPlotExtent(noonOffset, plotDuration);
-        removeAllPlotObjects();
-    }
+    setSecondaryLimits(times[0], times.last(), altitudeAxisMin, altitudeAxisMax);
+    axis(KPlotWidget::BottomAxis)->setTickLabelFormat('t');
+    axis(KPlotWidget::TopAxis)->setTickLabelFormat('t');
+    axis(KPlotWidget::TopAxis)->setTickLabelsShown(true);
+    setGeoLocation(geo);
 
+    setSunRiseSetTimes(ksal->getSunRise(), ksal->getSunSet());
+    setDawnDuskTimes(ksal->getDawnAstronomicalTwilight(), ksal->getDuskAstronomicalTwilight());
+    setMinMaxSunAlt(ksal->getSunMinAlt(), ksal->getSunMaxAlt());
+    setMoonRiseSetTimes(ksal->getMoonRise(), ksal->getMoonSet());
+    setMoonIllum(ksal->getMoonIllum());
+
+    const double noonOffset = times[0] - -12;
+    const double plotDuration = times.last() - times[0];
+    setPlotExtent(noonOffset, plotDuration);
+    removeAllPlotObjects();
+
+    tips.clear();
+    plotOverlay(times, alts, lineWidth, color, label);
+}
+
+void AVTPlotWidget::plotOverlay(const QVector<double> &times, const QVector<double> &alts, int lineWidth,
+                                Qt::GlobalColor color, const QString &label)
+{
+    KPlotObject *po = new KPlotObject(color, KPlotObject::Lines, lineWidth);
+    QPen pen;
+    pen.setWidth(lineWidth);
+    pen.setColor(color);
+    po->setLinePen(pen);
+
+    Tip tip;
+    tip.label = label;
     for (int i = 0; i < times.size(); ++i)
+    {
         po->addPoint(times[i], alts[i]);
+        if (!label.isEmpty())
+        {
+            QPointF p = toXY(times[i], alts[i]);
+            tip.points.append(p);
+        }
+    }
     addPlotObject(po);
-
+    if (!label.isEmpty())
+        tips.append(tip);
     update();
 }
 
