@@ -8,13 +8,15 @@
 
 #include "ui_imagingplanner.h"
 #include "catalogsdb.h"
-#include <QPointer>
+
 #include <QDialog>
 #include <QDir>
 #include <QFuture>
 #include <QFutureWatcher>
-#include <QSortFilterProxyModel>
 #include <QMenu>
+#include <QNetworkAccessManager>
+#include <QPointer>
+#include <QSortFilterProxyModel>
 
 class QStandardItemModel;
 class QStandardItem;
@@ -123,7 +125,8 @@ protected slots:
     void searchAstrobin();
     void searchWikipedia();
     void searchSimbad();
-    void searchNGCICImages();
+    void searchSpecialWebPageImages();
+ 
     void recompute();
     void sorry(const QString &message);
 
@@ -172,6 +175,8 @@ protected:
     QString defaultDirectory() const;
     QString findDefaultCatalog() const;
     bool getKStarsCatalogObject(const QString &name, CatalogObject *catObject);
+    bool internetNameSearch(const QString &name, bool abellPlanetary, int abellNumber, CatalogObject * catObject);
+
     bool addCatalogItem(const KSAlmanac &ksal, const QString &name, int flags = 0);
     QUrl getAstrobinUrl(const QString &target, bool requireAwards, bool requireSomeFilters, double minRadius, double maxRadius);
     void popupAstrobin(const QString &target);
@@ -224,7 +229,12 @@ protected:
     void adjustWindowSize();
 
     // Used for debugging the object lists.
-    void checkTargets();
+    void checkTargets(bool justCheckCurrentCatalog = false);
+    void checkTargets2(bool backwards = false);
+
+    void adjustSpecialWebPageButton(const QString &name);
+    bool checkIfPageExists(const QString &urlString);
+    QNetworkAccessManager m_networkManager;
 
     ImagingPlannerUI *ui { nullptr };
 
@@ -244,6 +254,7 @@ protected:
     QPointer<ImagingPlannerPopup> m_PopupMenu;
 
     double m_MinMoon = 30.0;
+    double m_MaxMoonAltitude = 90.0;
     double m_MinAltitude = 30.0;
     double m_MinHours = 0;
     bool m_UseArtificialHorizon = true;
